@@ -3,7 +3,7 @@ IMGO - Process, augment, and balance image data.
 ------------------------------------------------
 UPTOOLS module: 
 
-Last updated: version 2.4.0
+Last updated: version 2.4.1
 
 Classes
 -------
@@ -485,13 +485,18 @@ def auto_rescale(img, dim):
 
     scale = (dim, dim)
 
+    if img.shape[2] == 1:
+        img_array = np.expand_dims(img, 3)
+    else:
+        img_array = img
+
     if raw_dims < dim:
         scaled_img = cv2.resize(
-            img, scale, interpolation=cv2.INTER_CUBIC
+            img_array, scale, interpolation=cv2.INTER_CUBIC
         )
     else:
         scaled_img = cv2.resize(
-            img, scale, interpolation=cv2.INTER_AREA
+            img_array, scale, interpolation=cv2.INTER_AREA
         )
 
     return scaled_img
@@ -2013,7 +2018,9 @@ class Image_Dataset:
                 else:
                     X_train_aug.append(self.shadow["train"][0][x])
 
-            self.shadow["train"][0] = np.array(X_train_aug)
+            self.shadow["train"][0] = np.expand_dims(
+                np.array(X_train_aug), 3
+            )
 
             if self.reduce == "std":
                 if self.dims == "various":
